mod config;
mod msg;
mod notification;
mod pages;

use actix_web::*;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    std::env::set_var("RUST_LOG", "info");
    std::env::set_var("RUST_BACKTRACE", "1");
    env_logger::init();

    let conf = config::Config::new();

    pages::assets::cache_bootstrap().await;

    HttpServer::new(move || {
        let logger = actix_web::middleware::Logger::default();
        App::new()
            .wrap(logger)
            .app_data(web::Data::new(conf.clone()))
            .service(pages::index::index)
            // Assets
            .service(pages::assets::bootstrap_js)
            .service(pages::assets::bootstrap_css)
            .service(pages::assets::bootstrap_icons)
            .service(pages::assets::bootstrap_font1)
            .service(pages::assets::bootstrap_font2)
            .service(pages::assets::wallpaper)
            .service(pages::assets::me_img)
            .service(pages::index::public_key)
            .service(pages::index::mirrors)
            .service(pages::index::message_page)
            .service(pages::index::message_post)
    })
    .bind(("0.0.0.0", 8080))?
    .run()
    .await
}
