pub fn is_browser(req: &actix_web::HttpRequest) -> bool {
    let ua = req
        .headers()
        .get("user-agent")
        .unwrap()
        .to_str()
        .unwrap()
        .to_lowercase();
    if ua.contains("chrome") || ua.contains("safari") || ua.contains("firefox") {
        return true;
    }
    return false;
}

pub fn get_host(r: &actix_web::HttpRequest) -> String {
    let res = r.headers().get("HOST").unwrap().to_str().unwrap();
    return res.to_string();
}

pub fn get_host_address(r: &actix_web::HttpRequest) -> String {
    let res = r.headers().get("HOST").unwrap().to_str().unwrap();
    let res: Vec<&str> = res.split(":").collect();
    let res = res.first().unwrap();
    return res.to_string();
}

pub fn is_onion(r: &actix_web::HttpRequest) -> bool {
    return get_host_address(r).ends_with("onion");
}

pub fn is_i2p(r: &actix_web::HttpRequest) -> bool {
    return get_host_address(r).ends_with("i2p");
}

pub fn dynamic_link(
    inner: &str,
    normal_link: &str,
    onion: Option<&str>,
    i2p: Option<&str>,
    req: &actix_web::HttpRequest,
) -> String {
    if is_onion(req) {
        let href = onion.unwrap_or(normal_link);
        return format!("<a href={href}> {inner} </a>");
    }
    if is_i2p(req) {
        let href = i2p.unwrap_or(normal_link);
        return format!("<a href={href}> {inner} </a>");
    }
    return format!("<a href={normal_link}> {inner} </a>");
}
